Plotting fermi3d spin_texture — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

Note

Go to the end to download the full example code.

# Plotting fermi3d spin_texture

Symmetry does not currently work! Make sure for fermi surface calculations turn off symmetry

Plotting fermi3d spin_texture example.

First download the example files with the code below. Then replace data_dir below.

Downloading example

     data_dir = pyprocar.download_example(save_dir='',
                                 material='Fe',
                                 code='vasp',
                                 spin_calc_type='non-colinear',
                                 calc_type='fermi')

    # sphinx_gallery_thumbnail_number = 1

    import pyvista

    # You do not need this. This is to ensure an image is rendered off screen when generating exmaple gallery.
    pyvista.OFF_SCREEN = True

importing pyprocar and specifying local data_dir

    import os

    import pyprocar

    data_dir = os.path.join(
        pyprocar.utils.DATA_DIR, "examples", "Fe", "vasp", "non-colinear", "fermi"
    )

    # First create the FermiHandler object, this loads the data into memory. Then you can call class methods to plot
    # Symmetry only works for specfic space groups currently.
    # For the actual calculations turn off symmetry and set 'apply_symmetry'=False
    fermiHandler = pyprocar.FermiHandler(code="vasp", dirname=data_dir, apply_symmetry=True)

    WARNING : Fermi Energy not set! Set `fermi={value}`. By default, using fermi energy found in given directory.
    ---------------------------------------------------------------------------------------------------------------

## Spin Texture mode

    fermiHandler.plot_fermi_surface(
        mode="spin_texture",
        spin_texture=True,
        supercell=[2, 2, 2],
        texture_size=0.2,
        show=True,
        max_distance=0.3,  # This parameter controls the max distance to search for adjacent points for interpolation.
        # Lowering could speed the ploting, but too low could make the interpolation fail
    )

                    --------------------------------------------------------
                    There are additional plot options that are defined in a configuration file.
                    You can change these configurations by passing the keyword argument to the function
                    To print a list of plot options set print_plot_opts=True

                    Here is a list modes : plain , parametric , spin_texture , overlay
                    Here is a list of properties: fermi_speed , fermi_velocity , harmonic_effective_mass
                    --------------------------------------------------------

    ij,uvwabj->uvwabi

Total running time of the script: (0 minutes 10.006 seconds)

Gallery generated by Sphinx-Gallery